@@ -56,7 +56,7 @@ void p_entry(entry_obj *eop, int sep)
 
 int main(int argc, char *argv[])
 {
-    nis_result *res, *nres;
+    nis_result *res, *nres = NULL;
     int separator;
     char *name;
     int verbose = 0;
@@ -86,14 +86,14 @@ int main(int argc, char *argv[])
 
     if (verbose)
     {
-	printf("Result of object lookup:\n");
-	nis_print_result(res);
+	fprintf(stderr, "Result of object lookup:\n");
+	nis_fprint_result(res, 0, stderr);
     }
     
     separator = res->objects.objects_val[0].zo_data.objdata_u.ta_data.ta_sep;
 
     nis_freeresult(res);
-    
+
     res = nis_first_entry(name);
     if (res == NULL)
     {
@@ -117,8 +117,15 @@ int main(int argc, char *argv[])
 	     ((nres = nis_next_entry(name, &res->cookie)),
 	      res = nres));
 
-    if (res->status != 0 && res->status != 1)
+    if (res->status != NIS_SUCCESS &&
+	res->status != NIS_S_SUCCESS)
+    {
+	if ((res->status == NIS_NOTFOUND ||
+	     res->status == NIS_S_NOTFOUND) && nres)
+	    exit(0);
+	
         nis_perror(res->status, argv[1]);
+    }
 	     
     exit(0);
 }
