@@ -30,31 +30,31 @@
 #include <netdb.h>
 
 
-void dns_setnetent(int stayopen)
+void _dns_setnetent(int stayopen)
 {
 }
 
 
-void dns_endnetent(void)
+void _dns_endnetent(void)
 {
 }
 
 
-struct netent *dns_getnetent(void)
+struct netent *_dns_getnetent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct netent *dns_getnetbyname(const char *name)
+struct netent *_dns_getnetbyname(const char *name)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct netent *dns_getnetbyaddr(unsigned long net, int type)
+struct netent *_dns_getnetbyaddr(unsigned long net, int type)
 {
     errno = ECONNREFUSED;
     return NULL;
