@@ -189,7 +189,7 @@ struct group *_getgrnam(const char *name)
 }
 
 
-struct group *_getgrgid(int gid)
+struct group *_getgrgid(gid_t gid)
 {
     struct group *gp;
 
