@@ -31,31 +31,31 @@
 
 
 
-void nis_sethostent(int stayopen)
+void _nis_sethostent(int stayopen)
 {
 }
 
 
-void nis_endhostent(void)
+void _nis_endhostent(void)
 {
 }
 
 
-struct hostent *nis_gethostent(void)
+struct hostent *_nis_gethostent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct hostent *nis_gethostbyname(const char *name)
+struct hostent *_nis_gethostbyname(const char *name)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct hostent *nis_gethostbyaddr(const char *addr,
+struct hostent *_nis_gethostbyaddr(const char *addr,
 				  int len, int type)
 {
     errno = ECONNREFUSED;
