@@ -25,8 +25,8 @@
 
 #include <stdio.h>
 #include <errno.h>
+#include <shadow.h>
 #include "nsswitch.h"
-#include "nsw_shadow.h"
 #include "bld/defs.h"
 
 static struct nsw *nswp = NULL;
