@@ -91,7 +91,7 @@ static struct passwd *pwent_parse(char *str, int len)
 }
 
 
-void yp_setpwent(void)
+void _yp_setpwent(void)
 {
     rewind_flag = 1;
     if (savekey)
@@ -99,7 +99,7 @@ void yp_setpwent(void)
 }
 
 
-void yp_endpwent(void)
+void _yp_endpwent(void)
 {
     rewind_flag = 1;
     if (savekey)
@@ -107,7 +107,7 @@ void yp_endpwent(void)
 }
 
 
-struct passwd *yp_getpwent(void)
+struct passwd *_yp_getpwent(void)
 {
     struct passwd *pw;
     char *map;
@@ -180,7 +180,7 @@ struct passwd *yp_getpwent(void)
 }
 
 
-struct passwd *yp_getpwuid(uid_t uid)
+struct passwd *_yp_getpwuid(uid_t uid)
 {
     struct passwd *pw;
     char *map;
@@ -211,7 +211,7 @@ struct passwd *yp_getpwuid(uid_t uid)
 }
 
 
-struct passwd *yp_getpwnam(const char *name)
+struct passwd *_yp_getpwnam(const char *name)
 {
     struct passwd *pw;
     char *map;
