@@ -34,7 +34,7 @@ main(int argc, char *argv[])
     struct netent *net;
 
 
-    net = nsw_getnetbyname(argv[1]);
+    net = getnetbyname(argv[1]);
 
     if (net)
 	print_network(net);
@@ -45,10 +45,3 @@ main(int argc, char *argv[])
 }
 
 
-
-
-
-
-
-
-
