@@ -25,7 +25,8 @@
 */
 
 #include <stdio.h>
-#include "yp_networks.h"
+#include <netdb.h>
+
 extern void print_network(struct netent *);
 
 int
